==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicMenuUI__24ChangeHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuUI$ChangeHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 89d5868b539b0a4 javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_plaf_basic_BasicMenuUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$method$_init$7ba31f1d1d7c381f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vmethods	javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_refs	javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicMenuUI__24ChangeHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuUI$ChangeHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 89d5868b539b0a4 javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_plaf_basic_BasicMenuUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$method$_init$7ba31f1d1d7c381f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vmethods	javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_refs	javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuUI__24ChangeHandler_H_ */
